==> core-0.3.0.tgz: package/lib/cache/CFMemcache.js <==
var Class = require('../class/Class.js').Class;
var Memcache = require('./Memcache.js').Memcache;
var assertions = require('../common/Assertions.js');

var CFMemcache = function(){
	this.Extends = Memcache;
	
    this._memory = {};

	this.initialize = function(options){
        this.parent(options);
	};
    
	this.get = function(key, callback){
        assertions.isString(key, Memcache.Exception.WRONG_TYPE);
        if(this._memory.hasOwnProperty(key)){
             this._memory[key].callbacks.push(callback);
        } else {
            // dodaje klucz do memory
            this._memory[key] = {
                data: null,
                callbacks: [callback]
            };
            var that = this;
            this.parent(key, function(data){
                that._memory[key].data = data;
                for(var cbIndex=0;cbIndex<that._memory[key].callbacks.length;cbIndex++){
                    that._memory[key].callbacks[cbIndex](that._memory[key].data);
                }
                delete that._memory[key];
            });
        }
	};
    
    this.set = function(key, value, callback, lifeTime){
        assertions.isString(key, Memcache.Exception.WRONG_TYPE);
        if(this._memory.hasOwnProperty(key)){
            this._memory[key].data = value;
        }
        this.parent(key, value, callback, lifeTime);
    };
    
    this['delete'] = function(key, callback){
        assertions.isString(key, Memcache.Exception.WRONG_TYPE);
        if(this._memory.hasOwnProperty(key)){
            this._memory[key].data = null;
        }
        this.parent(key, callback);
    };

};
CFMemcache = new Class(new CFMemcache());
exports.CFMemcache = CFMemcache;

==> core-0.3.2.tgz: package/lib/cache/CFMemcache.js <==
var Class = require('../class/Class.js').Class;
var Memcache = require('./Memcache.js').Memcache;
var assertions = require('../common/Assertions.js');

var CFMemcache = function(){
	this.Extends = Memcache;
	
    this._memory = {};

	this.initialize = function(options){
        this.parent(options);
	};
    
	this.get = function(key, callback){
        assertions.isString(key, Memcache.Exception.WRONG_TYPE);
        if(this._memory.hasOwnProperty(key)){
             this._memory[key].callbacks.push(callback);
        } else {
            // dodaje klucz do memory
            this._memory[key] = {
                data: null,
                callbacks: [callback]
            };
            var that = this;
            this.parent(key, function(data){
                that._memory[key].data = data;
                for(var cbIndex=0,max=that._memory[key].callbacks.length;cbIndex<max;cbIndex++){
                    that._memory[key].callbacks[cbIndex](that._memory[key].data);
                }
                delete that._memory[key];
            });
        }
	};
    
    this.set = function(key, value, callback, lifeTime){
        assertions.isString(key, Memcache.Exception.WRONG_TYPE);
        if(this._memory.hasOwnProperty(key)){
            this._memory[key].data = value;
        }
        this.parent(key, value, callback, lifeTime);
    };
    
    this['delete'] = function(key, callback){
        assertions.isString(key, Memcache.Exception.WRONG_TYPE);
        if(this._memory.hasOwnProperty(key)){
            this._memory[key].data = null;
        }
        this.parent(key, callback);
    };

};
CFMemcache = new Class(new CFMemcache());
exports.CFMemcache = CFMemcache;
